"""
Exceptions personnalisées pour Atmo Data Wrapper
"""


class AtmoDataException(Exception):
    """Exception de base pour les erreurs liées à l'API Atmo Data"""
    
    def __init__(self, message: str, status_code: int = None, response_data: dict = None):
        super().__init__(message)
        self.status_code = status_code
        self.response_data = response_data
        
    def __str__(self) -> str:
        if self.status_code:
            return f"AtmoDataException ({self.status_code}): {super().__str__()}"
        return f"AtmoDataException: {super().__str__()}"


class AuthenticationError(AtmoDataException):
    """Erreur d'authentification"""
    pass


class ValidationError(AtmoDataException):
    """Erreur de validation des paramètres"""
    pass


class APIError(AtmoDataException):
    """Erreur de l'API Atmo Data"""
    pass


class NetworkError(AtmoDataException):
    """Erreur de réseau"""
    pass


class DataError(AtmoDataException):
    """Erreur dans le traitement des données"""
    pass