# Notice Technique - Indice ATMO

**Guide de calcul en application de l'arrêté du 10 juillet 2020**

---

## Informations générales

- **Version** : 14 décembre 2020
- **Organisme** : Atmo France
- **Contact** : contact@atmo-france.org
- **Site web** : http://www.atmo-france.org
- **Adresse** : 7 rue Crillon
- **Téléphone** : 09 72 62 73 95

---

## Table des matières

1. [Préambule](#préambule)
2. [Historique – mise en place](#1-historique--mise-en-place)
3. [Définitions](#2-définitions)
4. [Objectifs de l'indice ATMO](#3-objectifs-de-lindice-atmo)
5. [Règles de calcul de l'indice ATMO](#4-règles-de-calcul-de-lindice-atmo)
6. [Limites de l'indice](#5-limites-de-lindice)
7. [Annexes](#annexes)

---

## Préambule

L'indice ATMO est un indicateur journalier qualificatif de la qualité de l'air. Il se décline en six qualificatifs définis selon différentes classes pour cinq polluants : « bon », « moyen », « dégradé », « mauvais », « très mauvais », « extrêmement mauvais ». 

Il intègre les polluants réglementés que l'on rencontre au quotidien :
- Les particules en suspension (PM₁₀ et PM₂.₅)
- Le dioxyde d'azote (NO₂)
- L'ozone (O₃)
- Le dioxyde de soufre (SO₂)

### Caractéristiques principales

- **Calcul obligatoire** sur l'ensemble du territoire français (France métropolitaine et outre-mer)
- **Périmètre géographique** ne pouvant dépasser celui de l'établissement public de coopération intercommunale (EPCI)
- **Zone plus fine** à l'échelle de la commune possible
- **Représentation simplifiée** de la qualité de l'air quotidienne en situation « de fond »
- **Calcul par les AASQA** à partir de données de modélisation, météorologiques, d'inventaire des émissions et d'observation

### Base réglementaire

Les modalités de calcul de cet indice sont précisées dans l'arrêté du 10 juillet 2020 relatif à l'indice de la qualité de l'air ambiant.

---

## 1) Historique – mise en place

### Création et évolution

L'indice ATMO réglementaire a été créé en **1994** à l'initiative du ministère chargé de l'Environnement et de plusieurs Associations agréées de surveillance de la qualité de l'air (AASQA).

### Base légale

- **Article R 221-5** du code de l'environnement : prévoit la mise à disposition de l'indice de la qualité de l'air
- **Arrêté du 10 janvier 2000** : rend obligatoire le calcul de l'indice Atmo sur tout le territoire national
- **Arrêté du 22 juillet 2004** : remplace l'arrêté de 2000, modifié par l'arrêté du 21 décembre 2011
- **Arrêté du 10 juillet 2020** : abroge l'arrêté du 22 juillet 2004 et constitue la base actuelle

### Processus de révision

La révision de l'indice ATMO a été alimentée par une réflexion menée au sein d'un groupe de travail mandaté par le ministère en charge de l'Environnement en février 2018, piloté par Atmo France, et rassemblant :
- L'ensemble des AASQA
- Le Bureau de la qualité de l'air (BQA)
- Le Service de la donnée et des études statistiques (SDES) de la DGEC

### Alignement européen

Ce nouvel indice ATMO a été conçu comme une déclinaison de l'indice horaire de l'Agence européenne pour l'environnement, avec :
- Un mode de calcul différent pour fournir un indice journalier
- Une information sur l'ensemble du territoire (pas uniquement à la station)
- Une méthode d'agrégation spatiale grâce à la modélisation

---

## 2) Définitions

### Termes techniques

**Modèle méso-échelle** : Modèle fonctionnant sur un domaine de plusieurs centaines de kilomètres et dont la résolution de l'ordre de quelques kilomètres permet d'évaluer la qualité de l'air en situation de fond.

**Modèle fine échelle** : Modèle caractérisé par une résolution de l'ordre de quelques dizaines de mètres permettant l'évaluation de la qualité de l'air en proximité des sources (ex: trafic routier).

### Échéances temporelles

Les modèles de dispersion atmosphérique effectuent des calculs pour plusieurs échéances :
- **j-1** : la veille
- **j0** : le jour-même  
- **j+1** : le lendemain
- **j+2** : le surlendemain

### Types de données

**Donnée assimilée** : Résulte de la combinaison des résultats de simulation et des observations pour limiter l'incertitude.

**Prévision statistique** : Révision issue de la correction statistique des simulations pour corriger les biais systématiques identifiés. Ce post-traitement utilise notamment les dernières mesures disponibles.

---

## 3) Objectifs de l'indice ATMO

Les objectifs de cet indice sont les suivants :

1. **Outil de communication** permettant de fournir une information synthétique sous une forme simple (couleur + qualificatif)
2. **Facilement compréhensible** par le grand public
3. **Qualifier la qualité de l'air** en situation de fond (pollution à laquelle personne n'échappe)
4. **Prévision** pour les journées J et J+1 a minima
5. **Couverture complète** de la zone de compétence de l'AASQA pour chacune de ses communes ou EPCI

---

## 4) Règles de calcul de l'indice ATMO

L'indice est calculé chaque jour. Il caractérise l'état de la qualité de l'air à l'échelle spatiale que l'AASQA aura jugée représentative. L'indice ATMO est diffusé soit à la commune, soit à l'EPCI, en fonction de ce que chaque AASQA considère pertinent sur son territoire.

### 4.1) Règle n°1 : Polluants concernés

Cinq polluants sont utilisés pour construire cet indice :
- **PM₂.₅** : Particules fines < 2.5 microns
- **PM₁₀** : Particules fines < 10 microns
- **O₃** : Ozone
- **NO₂** : Dioxyde d'azote
- **SO₂** : Dioxyde de soufre

### 4.2) Règle n°2 : Période prise en compte

- L'indice ATMO caractérise un état global de la qualité de l'air prévu sur **une journée**
- Calculé pour **24h** avec heure de départ à **0h TU**
- Diffusion quotidienne au plus tard à **12h (heure locale)** avec tolérance à 14h en cas de difficulté

### 4.3) Règle n°3 : Échelles des sous-indices

Un qualificatif est attribué à chaque polluant selon sa concentration. L'indice ATMO de la zone correspond au **qualificatif le plus dégradé**.

#### Tableau des seuils et qualificatifs

| Qualificatif | PM₂.₅ (μg/m³) | PM₁₀ (μg/m³) | NO₂ (μg/m³) | O₃ (μg/m³) | SO₂ (μg/m³) |
|--------------|---------------|--------------|-------------|------------|-------------|
| **Bon** | 0-10 | 0-20 | 0-40 | 0-50 | 0-100 |
| **Moyen** | 11-20 | 21-40 | 41-90 | 51-100 | 101-200 |
| **Dégradé** | 21-25 | 41-50 | 91-120 | 101-130 | 201-350 |
| **Mauvais** | 26-50 | 51-100 | 121-230 | 131-240 | 351-500 |
| **Très mauvais** | 51-75 | 101-150 | 231-340 | 241-380 | 501-750 |
| **Extrêmement mauvais** | >75 | >150 | >340 | >380 | >750 |

#### Codes couleur des qualificatifs

| Qualificatif | R | G | B | Hexadécimal |
|--------------|---|---|---|-------------|
| **Bon** | 80 | 240 | 230 | #50F0E6 |
| **Moyen** | 80 | 204 | 170 | #50CCAA |
| **Dégradé** | 240 | 230 | 65 | #F0E641 |
| **Mauvais** | 255 | 80 | 80 | #FF5050 |
| **Très mauvais** | 150 | 0 | 50 | #960032 |
| **Extrêmement mauvais** | 135 | 33 | 129 | #872181 |

#### Codes supplémentaires

| Qualificatif | R | G | B | Hexadécimal | Usage |
|--------------|---|---|---|-------------|-------|
| **Indisponible** | 221 | 221 | 221 | #DDDDDD | Absence de données |
| **Événement** | 136 | 136 | 136 | #888888 | Incident/accident |

### 4.4) Règle n°4 : Calcul de l'indice ATMO

#### Méthodologie préférentielle

Le calcul est réalisé **préférentiellement par modélisation** pour permettre une couverture complète du territoire pour J0 et J+1. À défaut, la mesure de fond peut être utilisée si elle est représentative.

#### Modèles méso-échelles (recommandés)

**Étapes de calcul** :
1. **En chaque point du modèle** : détermination du qualificatif et du/des polluant(s) responsable(s)
2. **Sélection des points** intersectant chaque commune
3. **Sélection du qualificatif le plus dégradé** parmi ceux calculés sur la commune

**Pour les communes sans point modèle** :
- Utiliser la valeur du point modèle le plus proche
- Sur-échantillonner le maillage sans interpolation
- Toute autre méthode garantissant la représentativité de fond

#### Calcul à l'EPCI

L'indice EPCI correspond à **l'indice communal le plus élevé** de l'EPCI.

### 4.5) Règle n°5 : Représentativité de la zone géographique

La représentativité spatiale de référence est donnée par les **stations de mesure de fond**. Selon la réglementation, les points de prélèvement sont représentatifs de plusieurs kilomètres carrés.

L'assimilation des données de ces stations et les prévisions statistiques associées doivent garantir la représentativité des résultats des modèles méso-échelles.

### 4.6) Règle n°6 : EPCI répartie entre deux régions

Les AASQA concernées par des EPCI à cheval entre deux régions se concertent pour une **communication cohérente**.

### 4.7) Règle n°7 : Calcul pour la veille

En cas de calcul d'un indice pour la veille (J-1), les données doivent s'appuyer sur des **données modélisées assimilées** (données brutes post-traitées pour intégrer les observations aux stations).

### 4.8) Règle n°8 : Diffusion et historique

#### Obligations de diffusion

Chaque AASQA doit publier les indices ATMO quotidiennement :
- **Flux WMS ou CSV** sur sa plateforme open data
- **Site internet** de l'AASQA
- **Informations obligatoires** : qualificatif, couleur, polluant(s) majoritaire(s)

#### Historique

En cas de calcul d'indice pour la veille, un **historique d'un an** de données en plus de l'année en cours est mis à disposition.

### 4.9) Règle n°9 : Événements spécifiques

En cas d'incident ou d'accident engendrant des émissions atmosphériques spécifiques rendant l'indice non représentatif, l'AASQA :
- **Informe** que l'indice n'est pas représentatif
- **Intègre** cette information dans le flux open data avec couleur et qualificatif spécifique (code "événement")

### 4.10) Règle n°10 : Cas particulier du SO₂

Lorsque l'AASQA mesure des niveaux importants de SO₂, notamment en cas d'incident industriel, elle peut :
- **Appliquer la règle n°9** (code événement)
- **Expertiser la situation** avec tous les outils disponibles et faire évoluer le sous-indice SO₂ en conséquence

---

## 5) Limites de l'indice

### Objectif et portée

L'indice ATMO permet de fournir une **information synthétique** sur la qualité globale de l'air de fond d'un territoire, dans l'état actuel des connaissances et de la réglementation.

### Ce que l'indice ne fait PAS

- **Ne caractérise pas** la qualité de l'air à proximité immédiate de sources fixes ou mobiles de pollution
- **Ne remplace pas** l'information spécifique lors des dépassements de seuils réglementaires
- **N'est pas adapté** pour les études épidémiologiques ou statistiques (utiliser les concentrations d'origine)
- **Ne rend pas compte** de la pollution cumulée sur de longues périodes (basé sur les seuils d'effet à court terme)

---

## Annexes

### Description du jeu de données - Indice ATMO 2021

#### Métadonnées générales

- **Jeu de données** : Indice Atmo de la qualité de l'air
- **Version** : 2021
- **Thème Inspire** : Zone de pollution potentielle
- **Résolution temporelle** : Jour
- **Résolution spatiale** : Commune ou EPCI
- **Fréquence de mise à jour** : Quotidienne à 14H locales
- **Profondeur des données** : Année N-1 complète + année en cours jusqu'à J+1 (voire J+2)
- **Licence** : ODbL 1.0 - Open Database Licence

#### Structure des flux de données

##### Flux WFS (obligatoire)
- **Type** : 1 seul WFS, 1 seule couche
- **Granularité** : Par commune ou EPCI sur la région
- **Polluants** : Tous dans la même couche
- **Profondeur** : N-1 et N jusqu'à J+1
- **Nom recommandé** : `ind_<région>` (ex: `ind_bretagne`)

##### Flux CSV (de secours)
- **Type** : 1 seul CSV, 1 seule table
- **Usage** : Obligatoire seulement si problème technique pour le WFS
- **Structure** : Identique au WFS

#### Champs obligatoires

| Nom du champ | Type | Description | Exemple |
|--------------|------|-------------|---------|
| **date_ech** | Date ISO 8601 | Date de valeur de l'indice (TU) | 2021-12-31T00:00:00Z |
| **code_qual** | Int | Classe de l'indice (1-6, 0 si absent, 7 si événement) | 1 |
| **lib_qual** | Varchar | Qualificatif textuel | Bon |
| **coul_qual** | Varchar | Couleur hexadécimale | #50F0E6 |
| **date_dif** | Date ISO 8601 | Date de diffusion (TU) | 2021-12-31T00:00:00Z |
| **source** | Varchar | Nom public de l'AASQA | Atmo Auvergne-Rhône-Alpes |
| **type_zone** | Varchar | Type de zone [commune, EPCI] | commune |
| **code_zone** | Varchar | Code commune INSEE ou code EPCI INSEE | 59350 |
| **lib_zone** | Varchar | Libellé commune ou EPCI | Marseille |

#### Codes par polluant

| Nom du champ | Type | Description | Exemple |
|--------------|------|-------------|---------|
| **code_no2** | Int | Classe sous-indice NO₂ (1-6, 0 si absent, 7 si événement) | 1 |
| **code_so2** | Int | Classe sous-indice SO₂ (1-6, 0 si absent, 7 si événement) | 2 |
| **code_o3** | Int | Classe sous-indice O₃ (1-6, 0 si absent, 7 si événement) | 3 |
| **code_pm10** | Int | Classe sous-indice PM₁₀ (1-6, 0 si absent, 7 si événement) | 4 |
| **code_pm25** | Int | Classe sous-indice PM₂.₅ (1-6, 0 si absent, 7 si événement) | 5 |

#### Coordonnées

| Nom du champ | Type | Description | Exemple |
|--------------|------|-------------|---------|
| **x_wgs84** | Float | Coordonnées en WGS84 EPSG:4326 | 3.0 |
| **y_wgs84** | Float | Coordonnées en WGS84 EPSG:4326 | 50.0 |
| **x_reg** | Float | Coordonnées réglementaires | 760889 |
| **y_reg** | Float | Coordonnées réglementaires | 6999650 |
| **epsg_reg** | Varchar | Système de projection réglementaire | 2154 |
| **geom** | Géométrie | Géométrie ponctuelle WKB | - |

#### Champs facultatifs - Concentrations

| Nom du champ | Type | Description |
|--------------|------|-------------|
| **conc_no2** | Int | Concentration de NO₂ en μg/m³ |
| **conc_so2** | Int | Concentration de SO₂ en μg/m³ |
| **conc_o3** | Int | Concentration d'O₃ en μg/m³ |
| **conc_pm10** | Int | Concentration de PM₁₀ en μg/m³ |
| **conc_pm25** | Int | Concentration de PM₂.₅ en μg/m³ |

#### Clé primaire
`date_ech` + `code_zone`

#### Exemple de gestion des versions
```
Je publie l'indice du 07-08-2020 en J+1 :
date_ech = 07-08-2020, date_diff = 06-08-2020

Je publie l'indice du 07-08-2020 en J+0 :
date_ech = 07-08-2020, date_diff = 07-08-2020
(remplace les valeurs précédentes)

Je publie l'indice du 07-08-2020 en J-1 (observé) :
date_ech = 07-08-2020, date_diff = 08-08-2020
(remplace les valeurs précédentes)
```

### Proposition méthodologique pour la représentativité

Pour analyser et garantir la représentativité spatiale des indices, il est proposé de comparer sur une année complète de données J-1 assimilées :

#### Méthodologie 1 (règle officielle)
**Indice du point modèle maximum** : Sélection de l'indice le plus dégradé parmi l'ensemble des points du modèle intersectant la commune.

#### Méthodologie 2 (validation)
**Comptage des points** : L'indice ayant le plus grand nombre de points du modèle intersectant la commune devient l'indice de la commune.

#### Méthodologie 3 (validation)
**Superficie pondérée** : Calcul par indice de la superficie cumulée intersectée entre les mailles du modèle et la commune. L'indice présentant la superficie la plus grande devient l'indice de la commune.

L'obtention de **résultats proches** entre ces méthodologies permet de valider l'échelle de diffusion retenue.

---

## Rédacteurs et validation

### Rédacteurs
- Yann Channac Mongredien (AtmoSud)
- Carole Flambard (Lig'Air)
- Delphine Guillaume (Atmo France)
- Jérôme Le Paih (ATMO Grand Est)
- Nathalie Pujol-Söhne (Atmo Hauts-de-France)
- Jérôme Rangognio (Lig'Air)
- Marine Tondelier (Atmo France)
- Romain Vidaud (Atmo Auvergne-Rhône-Alpes)
- Abderrazak Yahyaoui (Lig'Air)

### Relecteurs
- Cédric Messier, Julien Rude et Pascale Vizy (Bureau de la qualité de l'air / Ministère de la Transition écologique)
- Laurence Rouil (Ineris)

### Validation
**Validé en Comité de pilotage de surveillance le 15 décembre 2020**

---

*Document officiel - Atmo France - Version du 14 décembre 2020*